use strict;
use Test::More;

use_ok $_ for qw(
    Number::Phone::JP::AreaCode
    Number::Phone::JP::AreaCode::Data::Address2AreaCode
    Number::Phone::JP::AreaCode::Data::AreaCode2Address
);

done_testing;

